==> plonemeeting.portal.core-1.3.2.tar.gz: plonemeeting.portal.core-1.3.2/src/plonemeeting/portal/core/testing.py <==
# -*- coding: utf-8 -*-
from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneSandboxLayer
from plone.testing import z2
from plone.testing.zope import makeTestRequest

import plonemeeting.portal.core
import transaction


class PlonemeetingPortalCoreLayer(PloneSandboxLayer):

    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        import plone.restapi

        self.loadZCML(package=plone.restapi)
        self.loadZCML(package=plonemeeting.portal.core)

        # Patch collective.fingerpointing
        from collective.fingerpointing import utils

        def patched_getRequest():
            return makeTestRequest(environ={})

        utils.getRequest = patched_getRequest

    def setUpPloneSite(self, portal):
        applyProfile(portal, "plonemeeting.portal.core:default")
        transaction.commit()


PLONEMEETING_PORTAL_CORE_FIXTURE = PlonemeetingPortalCoreLayer()


PLONEMEETING_PORTAL_CORE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(PLONEMEETING_PORTAL_CORE_FIXTURE,),
    name="PlonemeetingPortalCoreLayer:IntegrationTesting",
)


PLONEMEETING_PORTAL_CORE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(PLONEMEETING_PORTAL_CORE_FIXTURE,),
    name="PlonemeetingPortalCoreLayer:FunctionalTesting",
)


PLONEMEETING_PORTAL_CORE_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        PLONEMEETING_PORTAL_CORE_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE,
    ),
    name="PlonemeetingPortalCoreLayer:AcceptanceTesting",
)


class PlonemeetingPortalDemoLayer(PlonemeetingPortalCoreLayer):
    def setUpPloneSite(self, portal):
        applyProfile(portal, "plonemeeting.portal.core:demo")
        transaction.commit()


PLONEMEETING_PORTAL_DEMO_FIXTURE = PlonemeetingPortalDemoLayer()


PLONEMEETING_PORTAL_DEMO_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(PLONEMEETING_PORTAL_DEMO_FIXTURE,),
    name="PlonemeetingPortalDemoLayer:FunctionalTesting",
)

==> plonemeeting.portal.core-1.3.3.1.tar.gz: plonemeeting.portal.core-1.3.3.1/src/plonemeeting/portal/core/testing.py <==
# -*- coding: utf-8 -*-

from collective.fingerpointing import utils as fp_utils
from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneSandboxLayer
from plone.testing import z2
from plone.testing.zope import makeTestRequest

import plonemeeting.portal.core
import transaction


__old__getRequest = fp_utils.getRequest


class PlonemeetingPortalCoreLayer(PloneSandboxLayer):

    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        import plone.restapi

        self.loadZCML(package=plone.restapi)
        self.loadZCML(package=plonemeeting.portal.core)

        # Patch collective.fingerpointing

        def patched_getRequest():
            return makeTestRequest(environ={})

        fp_utils.getRequest = patched_getRequest

    def setUpPloneSite(self, portal):
        applyProfile(portal, "plonemeeting.portal.core:default")
        transaction.commit()


PLONEMEETING_PORTAL_CORE_FIXTURE = PlonemeetingPortalCoreLayer()


PLONEMEETING_PORTAL_CORE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(PLONEMEETING_PORTAL_CORE_FIXTURE,),
    name="PlonemeetingPortalCoreLayer:IntegrationTesting",
)


PLONEMEETING_PORTAL_CORE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(PLONEMEETING_PORTAL_CORE_FIXTURE,),
    name="PlonemeetingPortalCoreLayer:FunctionalTesting",
)


PLONEMEETING_PORTAL_CORE_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        PLONEMEETING_PORTAL_CORE_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE,
    ),
    name="PlonemeetingPortalCoreLayer:AcceptanceTesting",
)


class PlonemeetingPortalDemoLayer(PlonemeetingPortalCoreLayer):
    def setUpPloneSite(self, portal):
        applyProfile(portal, "plonemeeting.portal.core:demo")
        transaction.commit()


PLONEMEETING_PORTAL_DEMO_FIXTURE = PlonemeetingPortalDemoLayer()


PLONEMEETING_PORTAL_DEMO_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(PLONEMEETING_PORTAL_DEMO_FIXTURE,),
    name="PlonemeetingPortalDemoLayer:FunctionalTesting",
)
